@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '0.28';
+  $CPAN::Perl::Releases::VERSION = '0.30';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -204,6 +204,10 @@ our $data =
     "tar.bz2" => "J/JE/JESSE/perl-5.14.1.tar.bz2",
     "tar.gz" => "J/JE/JESSE/perl-5.14.1.tar.gz",
   },
+  "5.14.2-RC1" => {
+    "tar.bz2" => "F/FL/FLORA/perl-5.14.2-RC1.tar.bz2",
+    "tar.gz" => "F/FL/FLORA/perl-5.14.2-RC1.tar.gz",
+  },
   "5.15.0" => {
     "tar.bz2" => "D/DA/DAGOLDEN/perl-5.15.0.tar.bz2",
     "tar.gz" => "D/DA/DAGOLDEN/perl-5.15.0.tar.gz",
@@ -324,7 +328,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.28
+version 0.30
 
 =head1 SYNOPSIS
 
